@@ -3,6 +3,7 @@ import logging
 import re
 from typing import Any, Dict, NamedTuple, cast
 
+from .modules import Antitheft, Cloud, Countdown, Emeter, Schedule, Time, Usage
 from .smartdevice import DeviceType, SmartDevice, SmartDeviceException, requires_update
 
 
@@ -34,11 +35,14 @@ TPLINK_KELVIN = {
     r"KL430": ColorTempRange(2500, 9000),
 }
 
+
+NON_COLOR_MODE_FLAGS = {"transition_period", "on_off"}
+
 _LOGGER = logging.getLogger(__name__)
 
 
 class SmartBulb(SmartDevice):
-    """Representation of a TP-Link Smart Bulb.
+    r"""Representation of a TP-Link Smart Bulb.
 
     To initialize, you have to await :func:`update()` at least once.
     This will allow accessing the properties using the exposed properties.
@@ -46,7 +50,7 @@ class SmartBulb(SmartDevice):
     All changes to the device are done using awaitable methods,
     which will not change the cached values, but you must await :func:`update()` separately.
 
-    Errors reported by the device are raised as :class:`SmartDeviceException`s,
+    Errors reported by the device are raised as :class:`SmartDeviceException`\s,
     and should be handled by the user of the library.
 
     Examples:
@@ -64,7 +68,7 @@ class SmartBulb(SmartDevice):
         >>> print(bulb.is_on)
         True
 
-        You can use the is_-prefixed properties to check for supported features
+        You can use the ``is_``-prefixed properties to check for supported features
         >>> bulb.is_dimmable
         True
         >>> bulb.is_color
@@ -106,13 +110,19 @@ class SmartBulb(SmartDevice):
     """
 
     LIGHT_SERVICE = "smartlife.iot.smartbulb.lightingservice"
-    TIME_SERVICE = "smartlife.iot.common.timesetting"
     SET_LIGHT_METHOD = "transition_light_state"
+    emeter_type = "smartlife.iot.common.emeter"
 
     def __init__(self, host: str) -> None:
         super().__init__(host=host)
-        self.emeter_type = "smartlife.iot.common.emeter"
         self._device_type = DeviceType.Bulb
+        self.add_module("schedule", Schedule(self, "smartlife.iot.common.schedule"))
+        self.add_module("usage", Usage(self, "smartlife.iot.common.schedule"))
+        self.add_module("antitheft", Antitheft(self, "smartlife.iot.common.anti_theft"))
+        self.add_module("time", Time(self, "smartlife.iot.common.timesetting"))
+        self.add_module("emeter", Emeter(self, self.emeter_type))
+        self.add_module("countdown", Countdown(self, "countdown"))
+        self.add_module("cloud", Cloud(self, "smartlife.iot.common.cloud"))
 
     @property  # type: ignore
     @requires_update
@@ -211,8 +221,14 @@ class SmartBulb(SmartDevice):
         if "on_off" not in state:
             state["on_off"] = 1
 
-        # This is necessary to allow turning on into a specific state
-        state["ignore_default"] = 1
+        # If we are turning on without any color mode flags,
+        # we do not want to set ignore_default to ensure
+        # we restore the previous state.
+        if state["on_off"] and NON_COLOR_MODE_FLAGS.issuperset(state):
+            state["ignore_default"] = 0
+        else:
+            # This is necessary to allow turning on into a specific state
+            state["ignore_default"] = 1
 
         light_state = await self._query_helper(
             self.LIGHT_SERVICE, self.SET_LIGHT_METHOD, state
