@@ -9,10 +9,13 @@ from kasa.smartdevice import (
     EmeterStatus,
     SmartDevice,
     SmartDeviceException,
+    merge,
     requires_update,
 )
 from kasa.smartplug import SmartPlug
 
+from .modules import Antitheft, Countdown, Emeter, Schedule, Time, Usage
+
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -26,7 +29,7 @@ def merge_sums(dicts):
 
 
 class SmartStrip(SmartDevice):
-    """Representation of a TP-Link Smart Power Strip.
+    r"""Representation of a TP-Link Smart Power Strip.
 
     A strip consists of the parent device and its children.
     All methods of the parent act on all children, while the child devices
@@ -38,7 +41,7 @@ class SmartStrip(SmartDevice):
     All changes to the device are done using awaitable methods,
     which will not change the cached values, but you must await :func:`update()` separately.
 
-    Errors reported by the device are raised as :class:`SmartDeviceException`s,
+    Errors reported by the device are raised as :class:`SmartDeviceException`\s,
     and should be handled by the user of the library.
 
     Examples:
@@ -80,6 +83,12 @@ class SmartStrip(SmartDevice):
         super().__init__(host=host)
         self.emeter_type = "emeter"
         self._device_type = DeviceType.Strip
+        self.add_module("antitheft", Antitheft(self, "anti_theft"))
+        self.add_module("schedule", Schedule(self, "schedule"))
+        self.add_module("usage", Usage(self, "schedule"))
+        self.add_module("time", Time(self, "time"))
+        self.add_module("countdown", Countdown(self, "countdown"))
+        self.add_module("emeter", Emeter(self, "emeter"))
 
     @property  # type: ignore
     @requires_update
@@ -242,16 +251,37 @@ class SmartStripPlug(SmartPlug):
         self._last_update = parent._last_update
         self._sys_info = parent._sys_info
         self._device_type = DeviceType.StripSocket
+        self.modules = {}
+        self.protocol = parent.protocol  # Must use the same connection as the parent
+        self.add_module("time", Time(self, "time"))
 
     async def update(self, update_children: bool = True):
         """Query the device to update the data.
 
         Needed for properties that are decorated with `requires_update`.
         """
-        self._last_update = await self.parent.protocol.query(
-            self._create_emeter_request()
+        await self._modular_update({})
+
+    def _create_emeter_request(self, year: int = None, month: int = None):
+        """Create a request for requesting all emeter statistics at once."""
+        if year is None:
+            year = datetime.now().year
+        if month is None:
+            month = datetime.now().month
+
+        req: Dict[str, Any] = {}
+
+        merge(req, self._create_request("emeter", "get_realtime"))
+        merge(req, self._create_request("emeter", "get_monthstat", {"year": year}))
+        merge(
+            req,
+            self._create_request(
+                "emeter", "get_daystat", {"month": month, "year": year}
+            ),
         )
 
+        return req
+
     def _create_request(
         self, target: str, cmd: str, arg: Optional[Dict] = None, child_ids=None
     ):
@@ -318,7 +348,7 @@ class SmartStripPlug(SmartPlug):
         info = self._get_child_info()
         on_time = info["on_time"]
 
-        return datetime.now() - timedelta(seconds=on_time)
+        return self.time - timedelta(seconds=on_time)
 
     @property  # type: ignore
     @requires_update
