@@ -25,7 +25,7 @@ SUPPORTED_DEVICES = glob.glob(
 )
 
 
-LIGHT_STRIPS = {"KL400", "KL430"}
+LIGHT_STRIPS = {"KL400", "KL430", "KL420"}
 VARIABLE_TEMP = {"LB120", "LB130", "KL120", "KL125", "KL130", "KL135", "KL430"}
 COLOR_BULBS = {"LB130", "KL125", "KL130", "KL135", *LIGHT_STRIPS}
 BULBS = {
@@ -53,7 +53,7 @@ PLUGS = {
     "KP401",
 }
 STRIPS = {"HS107", "HS300", "KP303", "KP400", "EP40"}
-DIMMERS = {"HS220"}
+DIMMERS = {"HS220", "KS220M"}
 
 DIMMABLE = {*BULBS, *DIMMERS}
 WITH_EMETER = {"HS110", "HS300", "KP115", *BULBS}
